#
# Conditional build:
%bcond_without	python3		# Python 3 binding
%bcond_without	readline	# readline in interactive programs
#
Summary:	Helsinki Finite-State Transducer (library and application suite)
Summary(pl.UTF-8):	Helsinki Finite-State Transducer (biblioteka i zestaw aplikacji)
Name:		hfst
Version:	3.11.0
Release:	3
License:	LGPL v3 (library), GPL v3 (tools)
Group:		Applications/Text
#Source0Download: https://github.com/hfst/hfst/releases
Source0:	https://github.com/hfst/hfst/releases/download/v%{version}/%{name}-%{version}.tar.gz
# Source0-md5:	6cbdddcb9ef28aa5681081a8a1dc6b54
Patch0:		%{name}-pc.patch
URL:		http://www.ling.helsinki.fi/kieliteknologia/tutkimus/hfst/
# bundled library is used
#BuildRequires:	SFST-devel
BuildRequires:	autoconf >= 2.62
BuildRequires:	automake >= 1:1.11
BuildRequires:	bison
BuildRequires:	flex >= 2.5.35
BuildRequires:	glib2-devel >= 1:2.16
BuildRequires:	libstdc++-devel
BuildRequires:	libtool >= 2:2.2
# disabled in sources
#BuildRequires:	libxml2-devel >= 2
BuildRequires:	ncurses-devel
# bundled library is used
#BuildRequires:	openfst-devel
BuildRequires:	pkgconfig >= 1:0.14
BuildRequires:	python >= 1:2.4
%{?with_python3:BuildRequires:	python3 >= 1:3.2}
%{?with_readline:BuildRequires:	readline-devel}
BuildRequires:	rpm-pythonprov
BuildRequires:	rpmbuild(macros) >= 1.714
%{?with_python3:BuildRequires:	swig-python}
BuildRequires:	zlib-devel
Requires:	glib2 >= 1:2.16
BuildRoot:	%{tmpdir}/%{name}-%{version}-root-%(id -u -n)

%description
The Helsinki Finite-State Transducer software is intended for the
implementation of morphological analysers and other tools which are
based on weighted and unweigted finite-state transducer technology.

%description -l pl.UTF-8
Pakiet HFST (Helsinki Finite-State Transducer) to oprogramowanie
służące do implementacji analizatorów morfologicznych i innych
narzędzi opartych na technice przetwarzania ze skończoną liczbą
stanów z wagami lub bez.

%package tagger
Summary:	HFST Tagger scripts
Summary(pl.UTF-8):	Skrypty HFST Tagger
License:	GPL v3
Group:		Applications/Text
Requires:	%{name} = %{version}-%{release}

%description tagger
HFST Tagger scripts written in Python.

%description tagger -l pl.UTF-8
Skrypty HFST Tagger napisane w Pythonie.

%package devel
Summary:	Header files for HFST library
Summary(pl.UTF-8):	Pliki nagłówkowe biblioteki HFST
License:	LGPL v3
Group:		Development/Libraries
Requires:	%{name} = %{version}-%{release}
#Requires:	SFST-devel
Requires:	glib2-devel >= 1:2.16
Requires:	libstdc++-devel
#Requires:	openfst-devel
Requires:	readline-devel

%description devel
Header files for HFST library.

%description devel -l pl.UTF-8
Pliki nagłówkowe biblioteki HFST.

%package static
Summary:	Static HFST library
Summary(pl.UTF-8):	Statyczna biblioteka HFST
License:	LGPL v3
Group:		Development/Libraries
Requires:	%{name}-devel = %{version}-%{release}

%description static
Static HFST library.

%description static -l pl.UTF-8
Statyczna biblioteka HFST.

%package -n python-hfst
Summary:	Python 2 binding for HFST library
Summary(pl.UTF-8):	Wiązanie Pythona 2 do biblioteki HFST
License:	LGPL v3
Group:		Libraries/Python
Requires:	%{name} = %{version}-%{release}

%description -n python-hfst
Python 2 binding for HFST library.

%description -n python-hfst -l pl.UTF-8
Wiązanie Pythona 2 do biblioteki HFST.

%package -n python3-hfst
Summary:	Python 3 binding for HFST library
Summary(pl.UTF-8):	Wiązanie Pythona 3 do biblioteki HFST
License:	LGPL v3
Group:		Libraries/Python
Requires:	%{name} = %{version}-%{release}

%description -n python3-hfst
Python 3 binding for HFST library.

%description -n python3-hfst -l pl.UTF-8
Wiązanie Pythona 3 do biblioteki HFST.

%prep
%setup -q
%patch0 -p1

%build
%{__libtoolize}
%{__aclocal}
%{__autoconf}
%{__autoheader}
%{__automake}
%configure \
	--enable-calculate \
	--enable-foma-wrapper \
	--enable-lexc \
	--enable-lexc-wrapper \
	--enable-proc \
	--disable-silent-rules \
	--enable-tagger \
	--enable-xfst \
	%{?with_readline:--with-readline} \
	--with-unicode-handler=glib

# parallel build is broken with foma backend
%{__make} -j1

cd python
%py_build
%if %{with python3}
%py3_build
%endif

%install
rm -rf $RPM_BUILD_ROOT
install -d $RPM_BUILD_ROOT%{_bindir}

%{__make} install \
	DESTDIR=$RPM_BUILD_ROOT

# obsoleted by pkgconfig
%{__rm} $RPM_BUILD_ROOT%{_libdir}/libhfst.la

# for transducer data
install -d $RPM_BUILD_ROOT%{_datadir}/hfst

cd python
%py_install
%py_postclean
%if %{with python3}
%py3_install
%endif

%clean
rm -rf $RPM_BUILD_ROOT

%post	-p /sbin/ldconfig
%postun	-p /sbin/ldconfig

%files
%defattr(644,root,root,755)
%doc AUTHORS NEWS README THANKS
%attr(755,root,root) %{_bindir}/hfst-*
%attr(755,root,root) %{_bindir}/hfst_foma
%attr(755,root,root) %{_bindir}/htwolcpre*
%attr(755,root,root) %{_libdir}/libhfst.so.*.*.*
%attr(755,root,root) %ghost %{_libdir}/libhfst.so.46
%dir %{_datadir}/hfst
%{_mandir}/man1/hfst-*.1*
%{_mandir}/man1/htwolcpre?.1*

%files tagger
%defattr(644,root,root,755)
%attr(755,root,root) %{_bindir}/hfst_tagger_compute_data_statistics.py
%{py_sitescriptdir}/hfst_tagger_compute_data_statistics.py[co]
%{py_sitescriptdir}/tagger_aux.py[co]
%{_mandir}/man1/hfst_tagger_compute_data_statistics.py.1*

%files devel
%defattr(644,root,root,755)
%attr(755,root,root) %{_libdir}/libhfst.so
%{_includedir}/hfst
%{_aclocaldir}/hfst.m4
%{_pkgconfigdir}/hfst.pc

%files static
%defattr(644,root,root,755)
%{_libdir}/libhfst.a

%files -n python-hfst
%defattr(644,root,root,755)
%attr(755,root,root) %{py_sitedir}/_libhfst.so
%{py_sitedir}/hfst
%{py_sitedir}/libhfst.py[co]
%{py_sitedir}/libhfst_swig-%{version}_beta-py*.egg-info

%if %{with python3}
%files -n python3-hfst
%defattr(644,root,root,755)
%attr(755,root,root) %{py3_sitedir}/_libhfst.cpython-*.so
%{py3_sitedir}/hfst
%{py3_sitedir}/libhfst.py
%{py3_sitedir}/__pycache__/libhfst.cpython-*.py[co]
%{py3_sitedir}/libhfst_swig-%{version}_beta-py*.egg-info
%endif
%changelog
* Thu Dec 29 2016 PLD Linux Team <feedback@pld-linux.org>
- For complete changelog see: http://git.pld-linux.org/?p=packages/hfst.git;a=log;h=master

* Thu Dec 29 2016 Arkadiusz Miśkiewicz <arekm@maven.pl> 3536848
- python 3.6
- release 3 (by relup.sh)

* Tue Oct 18 2016 Jan Rękorajski <baggins@pld-linux.org> 75e80b7
- rebuild with readline 7.0
- release 2 (by relup.sh)

* Fri Sep 02 2016 Jakub Bogusz <qboosh@pld-linux.org> 2c60465
- new Source0 URL, updated to 3.11.0

* Fri Sep 02 2016 Jakub Bogusz <qboosh@pld-linux.org> 34221a1
- updated to 3.9.1

* Mon Jan 11 2016 Jakub Bogusz <qboosh@pld-linux.org> 5f76d0f
- restore hfst-proc tool; release 2

* Mon Dec 28 2015 Jakub Bogusz <qboosh@pld-linux.org> 8fe469c
- updated to 3.9.0 (note: new soname)
- removed obsolete link patch
- package python parts

* Sat Jun 29 2013 Jakub Bogusz <qboosh@pld-linux.org> 575da81
- no parallel build with foma

* Fri Jun 28 2013 Jakub Bogusz <qboosh@pld-linux.org> 9d1cebd
- always enable foma, ensuring it's wrapped (external libfoma no longer linked)

* Fri Jun 28 2013 Jakub Bogusz <qboosh@pld-linux.org> 942c090
- enable lexc (needed for some apertium dicts)

* Fri Jun 28 2013 Jakub Bogusz <qboosh@pld-linux.org> f19640b
- updated to 3.4.5 (note: new soname)
- added link patch (remove unnecessary linking with libxml2)
- enabled readline for interactive programs

* Tue Aug 02 2011 Jakub Bogusz <qboosh@pld-linux.org> d788e1f
- updated to 3.2.0 (note: new soname)
- updated pc patch
- use glib as unicode-handler (more powerful than internal)

* Sat Jun 18 2011 Jakub Bogusz <qboosh@pld-linux.org> 0196388
- updated to 3.1.1 (note: new soname)

* Mon Jun 06 2011 Jakub Bogusz <qboosh@pld-linux.org> 1cc1cae
- updated to 3.1.0 (note: new soname)

* Sun May 29 2011 Jakub Bogusz <qboosh@pld-linux.org> 7cf9be2
- provide directory for HFST transducers data

* Fri May 27 2011 Jakub Bogusz <qboosh@pld-linux.org> 6dc89b8
- updated to 3.0.3
- updated pc patch

* Sun Apr 24 2011 Jakub Bogusz <qboosh@pld-linux.org> fee79ac
- updated to 3.0.2
- removed obsolete link,rules patches
- added pc patch
- by default build with SFST and openfst enabled, foma disabled

* Sat Nov 27 2010 Jakub Bogusz <qboosh@pld-linux.org> ca7f144
- new package
- link patch to fix libhfstlexc linking
- rules patch to fix flex/bison rules (conflicting .h[h]/.c[c] outputs)

